# sscanblue

Execute pre-configured EPICS/synApps sscans using Bluesky.

Package was developed to enable current users of the EPICS `sscan` record to use
tools provided by Bluesky, especially data storage, metadata, and access to live
data visualization.

- [User Guide](./docs/guide.md)
- [Install](./docs/install.md)
- [Predevelopment notes](./docs/notes.md)
